% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/organizations_operations.R
\name{organizations_detach_policy}
\alias{organizations_detach_policy}
\title{Detaches a policy from a target root, organizational unit (OU), or
account}
\usage{
organizations_detach_policy(PolicyId, TargetId)
}
\arguments{
\item{PolicyId}{[required] The unique identifier (ID) of the policy you want to detach. You can get
the ID from the ListPolicies or ListPoliciesForTarget operations.

The \href{https://en.wikipedia.org/wiki/Regex}{regex pattern} for a policy ID
string requires "p-" followed by from 8 to 128 lowercase or uppercase
letters, digits, or the underscore character (\\_).}

\item{TargetId}{[required] The unique identifier (ID) of the root, OU, or account that you want to
detach the policy from. You can get the ID from the ListRoots,
ListOrganizationalUnitsForParent, or ListAccounts operations.

The \href{https://en.wikipedia.org/wiki/Regex}{regex pattern} for a target ID
string requires one of the following:
\itemize{
\item \strong{Root} - A string that begins with "r-" followed by from 4 to 32
lowercase letters or digits.
\item \strong{Account} - A string that consists of exactly 12 digits.
\item \strong{Organizational unit (OU)} - A string that begins with "ou-"
followed by from 4 to 32 lowercase letters or digits (the ID of the
root that the OU is in). This string is followed by a second "-"
dash and from 8 to 32 additional lowercase letters or digits.
}}
}
\description{
Detaches a policy from a target root, organizational unit (OU), or
account.

If the policy being detached is a service control policy (SCP), the
changes to permissions for AWS Identity and Access Management (IAM)
users and roles in affected accounts are immediate.

Every root, OU, and account must have at least one SCP attached. If you
want to replace the default \code{FullAWSAccess} policy with an SCP that
limits the permissions that can be delegated, you must attach the
replacement SCP before you can remove the default SCP. This is the
authorization strategy of an "\href{https://docs.aws.amazon.com/organizations/latest/userguide/#orgs_policies_allowlist}{allow list}".
If you instead attach a second SCP and leave the \code{FullAWSAccess} SCP
still attached, and specify \code{"Effect": "Deny"} in the second SCP to
override the \code{"Effect": "Allow"} in the \code{FullAWSAccess} policy (or any
other attached SCP), you're using the authorization strategy of a "\href{https://docs.aws.amazon.com/organizations/latest/userguide/#orgs_policies_denylist}{deny list}".

This operation can be called only from the organization's management
account.
}
\section{Request syntax}{
\preformatted{svc$detach_policy(
  PolicyId = "string",
  TargetId = "string"
)
}
}

\examples{
\dontrun{
# The following example shows how to detach a policy from an OU:/n/n
svc$detach_policy(
  PolicyId = "p-examplepolicyid111",
  TargetId = "ou-examplerootid111-exampleouid111"
)
}

}
\keyword{internal}
